==> core-0.1.42.tgz: package/esm/models/History.js <==
import { define, observable, action } from '@formily/reactive';
var History = (function () {
    function History(context, props) {
        this.current = 0;
        this.history = [];
        this.updateTimer = null;
        this.maxSize = 100;
        this.context = context;
        this.props = props;
        this.push();
        this.makeObservable();
    }
    History.prototype.makeObservable = function () {
        define(this, {
            current: observable.ref,
            history: observable.shallow,
            push: action,
            undo: action,
            redo: action,
            goTo: action,
            clear: action,
        });
    };
    History.prototype.list = function () {
        return this.history;
    };
    History.prototype.push = function () {
        if (this.current < this.history.length - 1) {
            this.history = this.history.slice(0, this.current + 1);
        }
        this.current = this.history.length;
        this.history.push(this.context.serialize());
        var overSizeCount = this.history.length - this.maxSize;
        if (overSizeCount > 0) {
            this.history.splice(0, overSizeCount);
            this.current = this.history.length - 1;
        }
    };
    Object.defineProperty(History.prototype, "allowUndo", {
        get: function () {
            return this.history.length > 0 && this.current - 1 >= 0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(History.prototype, "allowRedo", {
        get: function () {
            return this.history.length > this.current + 1;
        },
        enumerable: false,
        configurable: true
    });
    History.prototype.redo = function () {
        var _a;
        if (this.allowRedo) {
            var item = this.history[this.current + 1];
            this.context.from(item);
            this.current++;
            if ((_a = this.props) === null || _a === void 0 ? void 0 : _a.onRedo) {
                this.props.onRedo(item);
            }
        }
    };
    History.prototype.undo = function () {
        var _a;
        if (this.allowUndo) {
            var item = this.history[this.current - 1];
            this.context.from(item);
            this.current--;
            if ((_a = this.props) === null || _a === void 0 ? void 0 : _a.onUndo) {
                this.props.onUndo(item);
            }
        }
    };
    History.prototype.goTo = function (index) {
        if (this.history[index]) {
            this.context.from(this.history[index]);
            this.current = index;
        }
    };
    History.prototype.clear = function () {
        this.history = [];
        this.current = 0;
    };
    return History;
}());
export { History };

==> core-0.5.3.tgz: package/esm/models/History.js <==
import { define, observable, action } from '@formily/reactive';
var History = /** @class */ (function () {
    function History(context, props) {
        this.current = 0;
        this.history = [];
        this.updateTimer = null;
        this.maxSize = 100;
        this.locking = false;
        this.context = context;
        this.props = props;
        this.push();
        this.makeObservable();
    }
    History.prototype.makeObservable = function () {
        define(this, {
            current: observable.ref,
            history: observable.shallow,
            push: action,
            undo: action,
            redo: action,
            goTo: action,
            clear: action,
        });
    };
    History.prototype.list = function () {
        return this.history;
    };
    History.prototype.push = function (type) {
        if (this.locking)
            return;
        if (this.current < this.history.length - 1) {
            this.history = this.history.slice(0, this.current + 1);
        }
        this.current = this.history.length;
        this.history.push({
            data: this.context.serialize(),
            timestamp: Date.now(),
            type: type,
        });
        var overSizeCount = this.history.length - this.maxSize;
        if (overSizeCount > 0) {
            this.history.splice(0, overSizeCount);
            this.current = this.history.length - 1;
        }
    };
    Object.defineProperty(History.prototype, "allowUndo", {
        get: function () {
            return this.history.length > 0 && this.current - 1 >= 0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(History.prototype, "allowRedo", {
        get: function () {
            return this.history.length > this.current + 1;
        },
        enumerable: false,
        configurable: true
    });
    History.prototype.redo = function () {
        var _a;
        if (this.allowRedo) {
            var item = this.history[this.current + 1];
            this.locking = true;
            this.context.from(item.data);
            this.locking = false;
            this.current++;
            if ((_a = this.props) === null || _a === void 0 ? void 0 : _a.onRedo) {
                this.props.onRedo(item);
            }
        }
    };
    History.prototype.undo = function () {
        var _a;
        if (this.allowUndo) {
            var item = this.history[this.current - 1];
            this.locking = true;
            this.context.from(item.data);
            this.locking = false;
            this.current--;
            if ((_a = this.props) === null || _a === void 0 ? void 0 : _a.onUndo) {
                this.props.onUndo(item);
            }
        }
    };
    History.prototype.goTo = function (index) {
        var _a;
        var item = this.history[index];
        if (item) {
            this.locking = true;
            this.context.from(item.data);
            this.locking = false;
            this.current = index;
            if ((_a = this.props) === null || _a === void 0 ? void 0 : _a.onGoto) {
                this.props.onGoto(item);
            }
        }
    };
    History.prototype.clear = function () {
        this.history = [];
        this.current = 0;
    };
    return History;
}());
export { History };
